# Notifications

## Playbook Settings


## Notification Settings
- Mail

- Slack

- Discord

- Telegram

- Github Issue

If you need any help, please reach out to us on [Discord](https://discord.gg/F6Uzz7fc2s) or via [Email](mailto:support@satori-ci.com)
